==> haskell-doctest-parallel-0.3.1-118-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-DS55IKvwdrjI3tRoip3yAF
key:                  doctest-parallel-0.3.1-DS55IKvwdrjI3tRoip3yAF
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  7a54fe49ed582cc860c9081c4181fb1b
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-DS55IKvwdrjI3tRoip3yAF
depends:
    Cabal-3.8.1.0 Glob-0.10.2-KsmqzAMtUBqD2GDD9ejCew base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-9DjaJmPzq6yDmIbvjBdAsg-spectests-modules

key:
    doctest-parallel-0.3.1-9DjaJmPzq6yDmIbvjBdAsg-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  d50cc859ca322b926affd4fe8a0811eb
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-9DjaJmPzq6yDmIbvjBdAsg-spectests-modules

depends:
    base-4.17.2.1 doctest-parallel-0.3.1-DS55IKvwdrjI3tRoip3yAF
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-parallel-0.3.1-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-K2kDoZhNDme93UmUAx0mcV
key:                  doctest-parallel-0.3.1-K2kDoZhNDme93UmUAx0mcV
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  f35791dd07d622378a0edcc9ef7411e6
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-K2kDoZhNDme93UmUAx0mcV
depends:
    Cabal-3.10.3.0 Glob-0.10.2-AazMZkVQvnZLFhxAAQxaE8 base-4.18.3.0
    base-compat-0.14.1-FK5GrXzRHJlIaqVbFVqjup
    code-page-0.2.1-KL0sq19EuMI4bUG2N1N8uf containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.301.0 ghc-9.6.7.20250817
    ghc-paths-0.1.0.12-FYbNroakwr3J9PgmQPEoze process-1.6.19.0
    random-1.2.1.3-FQDOWOOVQ4iCxkTbz7wiP5
    syb-0.7.3-6bDfgbHeBGt4PXgAoYKZmA transformers-0.6.1.0
    unordered-containers-0.2.20.1-7PiWvIDwvL86x9qoplFlpQ

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-K7kuJoYPKuAIJUOaekVRjm-spectests-modules

key:
    doctest-parallel-0.3.1-K7kuJoYPKuAIJUOaekVRjm-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  fb801634f2d081dc99b623e42d314fa4
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/doctest-parallel-0.3.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-K7kuJoYPKuAIJUOaekVRjm-spectests-modules

depends:
    base-4.18.3.0 doctest-parallel-0.3.1-K2kDoZhNDme93UmUAx0mcV
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
